@@ -9,7 +9,7 @@ BEGIN {
     $ENV{TEST2_ACTIVE} = 1;
 }
 
-our $VERSION = '1.302184';
+our $VERSION = '1.302187';
 
 
 my $INST;
@@ -680,6 +680,8 @@ sub run_subtest {
         };
     }
 
+    my $start_stamp = time;
+
     my ($ok, $err, $finished);
     T2_SUBTEST_WRAPPER: {
         # Do not use 'try' cause it localizes __DIE__
@@ -696,6 +698,8 @@ sub run_subtest {
         }
     }
 
+    my $stop_stamp = time;
+
     if ($params->{no_fork}) {
         if ($$ != $ctx->trace->pid) {
             warn $ok ? "Forked inside subtest, but subtest never finished!\n" : $err;
@@ -746,6 +750,8 @@ sub run_subtest {
         subtest_uuid => $hub->uuid,
         buffered     => $buffered,
         subevents    => \@events,
+        start_stamp  => $start_stamp,
+        stop_stamp   => $stop_stamp,
     );
 
     my $plan_ok = $hub->check_plan;
